@@ -405,6 +405,9 @@ class FS345(SerialBase):
     # API implementation
     #
 
+    def setup(self):
+        pass
+
     def coupon_identify_customer(self, customer, address, document):
         self._customer_name = customer
         self._customer_document = document
@@ -522,6 +525,9 @@ class FS345(SerialBase):
     def summarize(self):
         self.send_command(CMD_GET_X)
 
+    def open_till(self):
+        self.summarize()
+
     def close_till(self, previous_day=False):
         status = self._get_status()
         if self._is_open(status):
