@@ -83,6 +83,7 @@ class FiscalPrinter(BasePrinter):
         self.totalized_value = Decimal("0.0")
         self._capabilities = self._driver.get_capabilities()
         self._charset = self._driver.coupon_printer_charset
+        self.setup()
 
     def get_capabilities(self):
         return self._capabilities
@@ -90,6 +91,10 @@ class FiscalPrinter(BasePrinter):
     def _format_text(self, text):
         return encode_text(text, self._charset)
 
+    def setup(self):
+        log.info('setup()')
+        self._driver.setup()
+
     @capcheck(basestring, basestring, basestring)
     def identify_customer(self, customer_name, customer_address, customer_id):
         log.info('identify_customer(customer_name=%r, '
@@ -186,6 +191,7 @@ class FiscalPrinter(BasePrinter):
 
     def cancel_last_coupon(self):
         """Cancel the last non fiscal coupon or the last sale."""
+        log.info('cancel_last_coupon()')
         self._driver.cancel_last_coupon()
 
     @capcheck(int)
@@ -228,6 +234,10 @@ class FiscalPrinter(BasePrinter):
         log.info('has_pending_reduce() = %s' % pending)
         return pending
 
+    def open_till(self):
+        log.info('open_till()')
+        return self._driver.open_till()
+
     def close_till(self, previous_day=False):
         log.info('close_till(previous_day=%r)' % (previous_day,))
 
