@@ -447,7 +447,7 @@ class FiscNetECF(SerialBase):
                 taxes.append(('%04d' % int(desc), value, type))
         return taxes
 
-    def setup(self):
+    def _configure_printer(self):
         self._define_tax_name(0,
             "Suprimento".encode(self.coupon_printer_charset), entrada=True)
         self._define_tax_name(1,
@@ -501,6 +501,9 @@ class FiscNetECF(SerialBase):
     # ICouponPrinter implementation
     #
 
+    def setup(self):
+        pass
+
     def coupon_identify_customer(self, customer, address, document):
         self._customer_name = customer
         self._customer_document = document
@@ -563,7 +566,7 @@ class FiscNetECF(SerialBase):
         # The FISCnet protocol (the protocol used in this printer model)
         # doesn't have a command to totalize the coupon, so we just get
         # the discount/surcharge values and applied to the coupon.
-        
+
         value = discount and (discount * -1) or surcharge
         if value:
             self._send_command('AcresceSubtotal',
@@ -587,6 +590,9 @@ class FiscNetECF(SerialBase):
     def summarize(self):
         self._send_command('EmiteLeituraX')
 
+    def open_till(self):
+        self.summarize()
+
     def close_till(self, previous_day=False):
         status = self._get_status()
         if status & FLAG_DOCUMENTO_ABERTO:
