@@ -265,6 +265,9 @@ class Simple(object):
     # ICouponPrinter implementation
     #
 
+    def setup(self):
+        pass
+
     def coupon_identify_customer(self, customer, address, document):
         self._check()
         if document not in ['160.618.061-40',
@@ -429,6 +432,9 @@ class Simple(object):
         self.till_closed = False
         self._save_state()
 
+    def open_till(self):
+        self.summarize()
+
     def close_till(self, previous_day=False):
         self._check()
         if self.till_closed:
